@@ -23,7 +23,7 @@ use File::Basename;
 require Exporter;
 use vars qw($VERSION @ISA @EXPORT);
 
-$VERSION = '0.2.4';
+$VERSION = '0.200';
 @ISA     = qw(Exporter);
 @EXPORT  = qw(ok);
 
@@ -1124,23 +1124,24 @@ There is no support for the <ISINDEX> tag, which is deprecated.
 
 =back
 
-=head1 PUBLIC REPOSITORY
+=head1 WEBSITE
 
-CGI::Test now has a publicly accessible Git server provided by GitHub.com:
-L<http://github.com/nohuhu/CGI-Test>
+You can find information about CGI::Test and other related modules at:
 
-=head1 REPORTING BUGS
+	http://cgi-test.sourceforge.net
 
-Please use CPAN RT or e-mail your bug reports, ideas, questions etc to
-module's maintainer.
+=head1 PUBLIC CVS SERVER
+
+CGI::Test now has a publicly accessible CVS server provided by
+SourceForge (www.sourceforge.net).  You can access it by going to:
+
+	 http://sourceforge.net/cvs/?group_id=89570
 
 =head1 AUTHORS
 
-The original author is Raphael Manfredi.
+The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
 
-Steven Hilton was long time maintainer of this module.
-
-Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
+Send bug reports, hints, tips, suggestions to Steven Hilton F<E<lt>mshiltonj@mshiltonj.comE<gt>>.
 
 =head1 SEE ALSO
 
